==> etchibbs-spiral-1.1.1.tar.gz: etchibbs-spiral/commentform.js <==
/* vim600: et ts=4 sts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 EtchiBoard Project
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: commentform.js,v 1.6 2004/02/12 18:42:27 lseeker Exp $
 */

/* 이 파일은 변수 설정 후에 불러야함 */
function preview_wrap(src, n) {
    preview_icon(src, document.getElementById('iconp' + n));
}

function show_comment_form(n) {
    document.getElementById('comment_form' + n).innerHTML =
            '<input type="hidden" name="article" value="' + n + '" />' +
            '<input type="hidden" name="page" value="' + page + '" />' +
            '<table cellpadding="1" cellspacing="0"><tr>' +
            '<td>Name</td><td><input type="text" name="name" size="20" maxlength="30" value="' + cookie_name + '" /> ' +
            '<td rowspan="7" align="center" valign="middle" style="border: 1px solid; width: 268px"><img id="iconp' + n + '" src="' + icon_preview + '" alt="Icon Preview" /></td></tr>' +
            '<tr><td>Mail</td><td><input type="text" name="email" size="32" maxlength="100" value="' + cookie_mail + '" /></td></tr>' +
            '<tr><td>URL(*)</td><td><input type="text" name="homepage" size="32" maxlength="255" value="' + cookie_home + '" /></td></tr>' +
            '<tr><td>Password</td><td><input type="password" name="passwd" size="9" maxlength="30" /></td></tr>' +
            '<tr><td>Icon</td><td><select name="icon" onchange="preview_wrap(this.value, ' + n + ');">' +
            '<option value="none.jpg">(아이콘 없음)</option><option value="none.jpg">--------------------</option>' + icon_list + '</select></td></tr>' +
            '<tr><td colspan="2"><textarea name="ne" rows="6" cols="45"></textarea></td></tr>' +
            '<tr><td colspan="2" align="center"><input type="submit" name="submit_btn" value="Submit" /> <input type="reset" value="Reset" /> [<span onclick="document.getElementById(\'comment_form' + n + '\').innerHTML=\'\'" style="cursor: pointer">닫기</span>]</td></tr>' +
            '</table>';
    return false;
}

==> etchibbs-spiral-1.2.0.tar.gz: etchibbs-spiral/commentform.js <==
/* vim600: et ts=4 sts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 EtchiBoard Project
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: commentform.js,v 1.8 2004/03/15 07:23:43 lseeker Exp $
 */

/* 이 파일은 변수 설정 후에 불러야함 */
var icon_listing = '';

for (i = 0; i < icon_list.length; i++) {
    icon_listing += '<option value="' + icon_list[i] + '">' + icon_list[i] + '</option>';
}

function preview_wrap(src, n) {
    preview_icon(src, document.getElementById('iconp' + n));
}

function show_comment_form(n) {
    document.getElementById('comment_form' + n).innerHTML = '<input type="hidden" name="article" value="' + n + '" /><input type="hidden" name="page" value="' + page + '" />' +
            '<table cellpadding="0" cellspacing="1"><tr>' +
            '<td>Name</td><td><input type="text" name="name" size="20" maxlength="30" value="' + cookie_name + '" /> ' +
            '<td rowspan="7" align="center" valign="middle" style="border: 1px solid; width: 268px"><img id="iconp' + n + '" src="' + icon_preview + '" alt="Icon Preview" /></td></tr>' +
            '<tr><td>Mail</td><td><input type="text" name="email" size="32" maxlength="100" value="' + cookie_mail + '" /></td></tr>' +
            '<tr><td>URL(*)</td><td><input type="text" name="homepage" size="32" maxlength="255" value="' + cookie_home + '" /></td></tr>' +
            '<tr><td>Password</td><td><input type="password" name="passwd" size="9" maxlength="30" /></td></tr>' +
            '<tr><td>Icon</td><td><select name="icon" id="icon' + n + '" onchange="preview_wrap(this.value, ' + n + ');">' +
            '<option value="none.jpg">(아이콘 없음)</option><option value="none.jpg">--------------------</option>' + icon_listing + '</select></td></tr>' +
            '<tr><td colspan="2"><textarea name="ne" rows="6" cols="45"></textarea></td></tr>' +
            '<tr><td colspan="2" align="center"><input type="submit" name="submit_btn" value="Submit" /> <input type="reset" value="Reset" /> [<span onclick="document.getElementById(\'comment_form' + n + '\').innerHTML=\'\'" style="cursor: pointer">닫기</span>]</td></tr>' +
            '</table>';

    document.getElementById('icon' + n).value = now_icon;

    return false;
}
